﻿--------------------------------------------------------------------------------
-- QuickMark
-- Author:  stphung
-- Email:   stphung@gmail.com
--------------------------------------------------------------------------------

-- Constants -------------------------------------------------------------------
QuickMark_Name = "QuickMark";
QuickMark_Version = "2.1";
QuickMark_SET_RAID_TARGET_NO_MARK = 0;
QuickMark_DEFAULT_IS_VERTICAL = false;

-- Global state ----------------------------------------------------------------
QuickMark_isDisplayed = false;
-- QuickMark_isVertical

--------------------------------------------------------------------------------
-- Utility print function.
-- Returns void.
--
function QuickMark_Print(arg)
    DEFAULT_CHAT_FRAME:AddMessage(arg);
end

--------------------------------------------------------------------------------
-- ENTRY POINT
-- Called in QuickMarkForm.xml to bootstrap this addon.
-- Returns void.
--
function QuickMark_OnLoad()
    this:RegisterEvent('VARIABLES_LOADED');
    QuickMark_AddSlashCommandHandler();
    QuickMark_Print(QuickMark_Name .. " " .. QuickMark_Version 
                        .. " loaded.  Use /qm to display available commands.");
end

--------------------------------------------------------------------------------
-- Listener for the VARIABLES_LOADED event.
-- Returns void.
--
function QuickMark_OnEvent(event)
    if event == 'VARIABLES_LOADED' then
        if ( not QuickMark_isVertical ) then 
            QuickMark_isVertical = QuickMark_DEFAULT_IS_VERTICAL;
        end
    end
end

--------------------------------------------------------------------------------
-- Handler for slash commands.
-- Returns void.
--
function QuickMark_SlashCommandHandler( msg )
    if ( msg == "" ) then
        QuickMark_Print("Use /qm <command>");
        QuickMark_Print("   <command>: show, hide, flip, version");
    elseif ( msg == "show" ) then
        QuickMark_ShowForm(QuickMark_isVertical);
    elseif ( msg == "hide" ) then
        QuickMark_HideForm(QuickMark_isVertical);
    elseif ( msg == "flip" ) then
        QuickMark_FlipForm(QuickMark_isDisplayed);
    elseif ( msg == "version" ) then
        QuickMark_Print("You are currently using " .. QuickMark_Name .. " " .. QuickMark_Version .. ".");
    end
end

--------------------------------------------------------------------------------
-- Adds the slash commands for invoking QuickMark.
-- Returns void.
--
function QuickMark_AddSlashCommandHandler()
    SlashCmdList["QUICKMARK"] = QuickMark_SlashCommandHandler;
    SLASH_QUICKMARK1 = "/quickmark";
    SLASH_QUICKMARK2 = "/qm";
end

function QuickMark_MarkCurrentTarget ( icon )
    if ( GetRaidTargetIndex("target") == icon ) then
        SetRaidTarget("target", QuickMark_SET_RAID_TARGET_NO_MARK);
    else
        SetRaidTarget("target", icon);
    end
end

--------------------------------------------------------------------------------
-- Flips the form from horizontal to vertical or vice versa.
-- Returns void.
--
function QuickMark_FlipForm( isDisplayed )
    if ( isDisplayed ) then
        QuickMark_HideForm(QuickMark_isVertical);
        QuickMark_isVertical = not QuickMark_isVertical;
        QuickMark_ShowForm(QuickMark_isVertical);
    end
end

--------------------------------------------------------------------------------
-- Displays the form.
-- Returns void.
--
function QuickMark_ShowForm( isVertical )
    if ( isVertical ) then 
        QuickMarkVerticalForm:Show();
    else 
        QuickMarkHorizontalForm:Show();
    end
    QuickMark_isDisplayed = true;
end

--------------------------------------------------------------------------------
-- Hides the frame.
-- Returns void.
--
function QuickMark_HideForm( isVertical )
    if ( isVertical ) then 
        QuickMarkVerticalForm:Hide();
    else 
        QuickMarkHorizontalForm:Hide();
    end
    QuickMark_isDisplayed = false;
end